Learn R Programming

Sojourn.Data (version 0.3.0)

youth_wristCounts: Neural network for youth Sojourn method, taking activity count data from non-dominant-wrist-worn monitors

Description

Neural network for youth Sojourn method, taking activity count data from non-dominant-wrist-worn monitors

Usage

youth_wristCounts

Arguments

Format

From print(youth_wristCounts):

a 9-15-3 network with 198 weights inputs: Age SexM BMI VM_Q10 VM_Q25 VM_Q50 VM_Q75 VM_Q90 VM_lag1 output(s): .outcome options were - softmax modelling decay=0.1