reg.nn: Uniaxial neural network for use in the original uniaxial Sojourn method
Description
Uniaxial neural network for use in the original uniaxial Sojourn method
Usage
reg.nn
Arguments
Format
From print(reg.nn):
a 6-25-1 network with 207 weights inputs: X10. X25. X50. X75. X90. acf
output(s): oxy.METS.calculated options were - skip-layer connections linear
output units